#Skink analyses

#Reset R's Brain
rm(list = ls())

#load exploaratory libraries libraries
library(tidyverse)
library(here)

#Skink counts
#Read in colony data and assign it a name
Counts <- read.csv(here("Counts.csv")) %>%  #Skink Count Data 
  mutate(Test = lubridate::hm(Temp.Time))

#Check data
Counts

#Count data
Counts$ID <- as.factor(seq(1,40)) # create individual tree ID's for GLM
Counts$Colony <- as.factor(Counts$Colony) #Convert Colony numbers to characters
Counts$Dispersion <- seq(1,40) #For overdispersion
Counts$Temp.Time <- as.numeric(Counts$Temp.Time)

####SKINK COUNTS####

#Summay
#Time


#Raw data for table
Summary <- Counts %>%
  group_by(Weavers) %>% 
  summarise(Total = sum(Skinks),
            Mean= mean(Skinks),
            SD = sd(Skinks),
            n. = length(Skinks)) %>% 
  mutate(SE = SD/sqrt(n.))

print(Summary)
#                     Total     Mean    SD        n.      SE     
# Weavers abssent       26      1.3     0.80      20      0.179
# Weavers present       53      2.65    1.57      20      0.350

Floor <- Counts %>%
  group_by(Weavers) %>% 
  summarise(Total = sum(Floor),
            Mean= mean(Floor),
            SD = sd(Floor),
            n. = length(Floor)) %>% 
  mutate(SE = SD/sqrt(n.))

print(Floor)
#                     Total     Mean    SD        n.      SE     
# Weavers absent        3       0.15    0.366     20      0.0819
# Weavers present       16      0.8     0.894     20      0.2

#base R figure
culr <- c("darkgrey", "dimgrey") #colours for charts with two catergories

#Plot Raw Count data
par(mfrow = c(1,1), 
    mar = c(4,4,2,2)+1) # set margins so that it allows 2 graphs per figure

#Plot total counts
Plot.Total <- barplot(Summary$Mean, 
                      main = "",
                      cex.names = 1.4,
                      ylim = c(0,4),
                      ylab = list("Mean number of skinks observed", cex = 1.3),
                      col = culr)

#Add standard error bars
arrows(Plot.Total, Summary$Mean + Summary$SE, Plot.Total, Summary$Mean - Summary$SE,
       code = 3, angle = 90, length = 0.1)

#Add additional text to plot
mtext("Weavers Presence", side=1, line=3, adj= 5.5, cex=1.5)
mtext("a", side = 1, line = -22, adj = 0.1, cex = 1.4)
mtext("**", side =1, line = -18.5, adj = 0.5, cex = 2.5)

#Plot raw data of skinks counted on the floor
Plot.Floor <- barplot(Floor$Mean,
                      main = "",
                      cex.names = 1.4,
                      ylim = c(0,1),
                      ylab = list("Mean number of skinks away from the tree", cex = 1.2),
                      col = culr)

#Add standard error bars
arrows(Plot.Floor, Floor$Mean + Floor$SE, Plot.Floor, Floor$Mean - Floor$SE,
       code = 3, angle = 90, length = 0.1)

#Add additional text to plot
mtext("b", side = 1, line = -22, adj = 0.1, cex = 1.4)
mtext("**", side =1, line = -18.5, adj = 0.5, cex = 2.5)

#Stats ---------------------------------------------------------------------------------------

library("lme4")
library("car")
library("glmmTMB")
library("emmeans")
library("effects")

####Skink Count GLMM ####

#Count data at colony trees when weavers are and are not present
glmCounts <- glmmTMB(Skinks~Weavers+Time+(1|Colony),data = Counts, family = poisson)

summary(glmCounts)
Anova(glmCounts, type = "III")

em.vig <- emmeans(glmCounts, ~ Weavers, type = "response")
em.vig

Summary$lower.CL <- c(0.822, 2.029)
Summary$upper.CL <- c(1.85, 3.54)
#ggplot effects
ggplot(data = Summary, aes(x=Weavers, y=Mean, colour = Weavers))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL),size = 1.2, width=.1) +
  xlab("Weavers presence") + ylab("Mean number of skinks observed")+ 
  theme_classic()+
  ylim(0,4)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  theme(legend.position = "none") +
  annotate("text", x = 0.6, y = 4, label = "a)", size =6)+
  annotate("text", x = 1.5, y = 3.7, label = "**", size =12)

#Skinks away from the tree
Floor.TMB <- glmmTMB(Floor ~ Weavers + Time +(1|Colony),
                     data=Counts, family = poisson)
summary(Floor.TMB)
Anova(Floor.TMB)

em.vig <- emmeans(Floor.TMB, ~ Weavers, type = "response")
em.vig

Floor$lower.CL <- c(0.0457, 0.485)
Floor$upper.CL <- c(0.48, 1.34)
#ggpplot figure

ggplot(data = Floor, aes(x=Weavers, y=Mean, colour = Weavers))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Weavers presence") + ylab("Mean number of skinks away from the tree")+ 
  theme_classic()+
  ylim(0,1.5)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  theme(legend.position = "none") +
  annotate("text", x = 0.6, y = 1.5, label = "b)", size =6)+
  annotate("text", x = 1.5, y = 1.4, label = "**", size =12)

#FIDs----------------------------------------------------------------------------

#Skink counts
#Read in colony data and assign it a name
FID <- read.csv(here("FIDs.csv")) %>%  #Skink Count Data 
  mutate(FIDmeters = Skink.FID/100) #convert centremetres in metres

#Check data
print(Counts)

#FID Data
FID$ID <- as.factor(seq(1,68)) #Create individual tree ID's
FID$Tree <- as.factor(FID$Tree)
FID$Dispersion <- as.numeric(seq(1,68))
FID$Temp.Time <- as.numeric(FID$Temp.Time)
FID$Pair <- as.factor(FID$Pair)

#Summary Data

FID.summary <- FID %>% 
  group_by(Colony) %>% 
  summarise(Mean = mean(FIDmeters),
            SD = sd(FIDmeters),
            n. = length(FIDmeters)) %>% 
  mutate(SE = SD/sqrt(n.))
        
print(FID.summary)
#                   Mean    SD      n.    SE
#Non-Colony tree    3.22    2.5     34    0.428
#Colony tree        7.83    7.61    34    1.31

#plot mean FIDS
par(mfrow = c(1,1),  #change margins so that it returns to only one chart per page
    mar = c(4,8,4,8)+1)

#plot data
Fidsplot <- barplot(FID.summary$Mean,
                    ylim = c(0, 12),
                    ylab = list("Flight Initiation Distance (m)", cex = 1.5),
                    xaxt = "n",
                    col = c("white", "grey"))
#add text        
mtext("non-colony tree", side = 1, line = 1., adj = 0.1, cex = 1.5)
mtext("colony tree", side = 1, line = 1, adj = 0.82, cex = 1.5)

#add error bars
arrows(Fidsplot, FID.summary$Mean - FID.summary$SE, Fidsplot, FID.summary$Mean + FID.summary$SE,
       code = 3, angle = 90, length = 0.1)

       #add level of significance
mtext("***", side =1, line = -20, adj = 0.5, cex = 2.5)



####FID STATS####

#Skink Weavers Presence FID
FID.glmm <- glmmTMB(Skink.FID ~ Colony + Temp.Time + (1|Tree), data = FID, family = nbinom2)
summary(FID.glmm)

Anova(FID.glmm, type = "III")

em.vig <- emmeans(FID.glmm, ~ Colony, type = "response")
em.vig

FID.summary$lower.CL <- c(5.15,2.24)
FID.summary$upper.CL <- c(9.23,3.98)

#ggplot
ggplot(data = FID.summary, aes(x=Colony, y=Mean, colour = Colony))+
  geom_line()+
  geom_point(size = 5)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("") + ylab("Flight Initiation Distance (m)")+ 
  theme_classic()+
  ylim(0,10)+
  theme(axis.text=element_text(size=20),
        axis.title=element_text(size=20),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  theme(legend.position = "none") +
  annotate("text", x = 1.5, y = 9.5, label = "***", size =12)


#Correlation skink FID v Weaver FID

#subset data so that ony data from FID with weavers 
Skink.Colony <- subset(FID, Colony =="yes")

cor.test(Skink.Colony$Skink.FID, Skink.Colony$Weaver.FID) #p = 0.85


#####Playback Analysis############################################################################################### 

#Reset R's Brain
rm(list = ls())

Playback <- read.csv(here("Playbacks.csv")) #Skink Count Data 
  
Playback$Period <- as.factor(Playback$Period)
Playback$Treatment <- as.factor(Playback$Treatment)
Playback$Colony <-as.factor(Playback$Colony)

Playback$TreeID <- as.factor(Playback$TreeID)
Playback$PairID <- as.factor(Playback$PairID)

Playback$Flee <- as.factor(Playback$Flee)
Playback$Order <-as.factor(Playback$Order)

print(Playback)

#Stats
#Full model - Vigilance
Vig.TMB <- glmmTMB(Head~Period*Treatment*Colony+Temp.Time + Order + (1|PairID/TreeID), 
                  data = Playback, family = nbinom1)

summary(Vig.TMB)
Anova(Vig.TMB, Type =  "III")

em.vig <- emmeans(Vig.TMB, pairwise ~ Period:Treatment:Colony, type = "response")
em.vig

#move emmeans results into a data frame
vigilance.means <- em.vig$emmeans %>% 
  as.data.frame()

Col.Alarm <- vigilance.means %>% 
  filter(Colony =="Yes",
         Treatment =="Alarm")

#ggplot

ggplot(data = Col.Alarm, aes(x=Period, y=response, colour = Period))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("") + ylab("Number of head movements")+ 
  theme_classic()+
  ylim(0,6)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("", ""))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  annotate("text", x = 1.5, y = 5.5, label = "***", size =12)+
  annotate("text", x = 0.6, y = 6, label = "a)", size =6)

Col.Control <- vigilance.means %>% 
  filter(Colony =="Yes",
         Treatment =="Control")

ggplot(data = Col.Control, aes(x=Period, y=response, colour = Period))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("") + ylab("Head movements")+ 
  theme_classic()+
  ylim(0,6)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("", ""))+
  theme(legend.position = "none") +
  annotate("text", x = 0.6, y = 6, label = "b)", size =6)

Non.Alarm <- vigilance.means %>% 
  filter(Colony =="No",
         Treatment =="Alarm")

ggplot(data = Non.Alarm, aes(x=Period, y=response, colour = Period))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Treatment") + ylab("Number of head movements")+ 
  theme_classic()+
  ylim(0,8)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Pre-stimulus", "Alarm"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  annotate("text", x = 1.5, y = 7.5, label = "***", size =12)+
  annotate("text", x = 0.6, y = 8, label = "c)", size =6)

Non.Control <- vigilance.means %>% 
  filter(Colony =="No",
         Treatment =="Control")

ggplot(data = Non.Control, aes(x=Period, y=response, colour = Period))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Treatment") + ylab("Number of head movements")+ 
  theme_classic()+
  ylim(0,8)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Pre-stimulus", "Stimulus"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  annotate("text", x = 1.5, y = 7.5, label = "**", size =12)+
  annotate("text", x = 0.6, y = 8, label = "d)", size =6)

Tree.Alarm <- vigilance.means %>% 
  filter(Treatment =="Alarm",
         Period =="2")

ggplot(data = Tree.Alarm, aes(x=Colony, y=response, colour = Colony))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Alarm") + ylab("Head movements")+ 
  theme_classic()+
  ylim(0,8)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Non-colony", "Colony"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  #annotate("text", x = 1.5, y = 14, label = "", size =12)+
  annotate("text", x = 0.6, y = 8, label = "a)", size =6)

Tree.Control <- vigilance.means %>% 
  filter(Treatment =="Control",
         Period =="2")

ggplot(data = Tree.Control, aes(x=Colony, y=response, colour = Colony))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Control") + ylab("")+ 
  theme_classic()+
  ylim(0,8)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Non-colony", "Colony"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  annotate("text", x = 1.5, y = 7.5, label = "", size =12)+
  annotate("text", x = 0.6, y = 8, label = "b)", size =6)


#Flee----------------------------------------------------------------------------------------

Flee <- read.csv(here("Flee.csv")) #Read in Flee dataset

Flee.TMB <-  glmmTMB(Stimflee~Treatment*Colony + Time + Order + (1|PairID/TreeID), 
                     data = Flee, family = binomial)

summary(Flee.TMB)
Anova(Flee.TMB, Type ="III")

em.flee <- emmeans(Flee.TMB, pairwise ~ Treatment:Colony, type = "response")
em.flee
#Transfer plot effects into a data frame for use in ggplot2
flee.means <- em.flee$emmeans %>% 
  as.data.frame()

Flee.Colony <- flee.means %>% 
  filter(Colony =="yes")

ggplot(data = Flee.Colony, aes(x=Treatment, y=prob, colour = Treatment))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Colony tree") + ylab("Probability of skinks fleeing")+ 
  theme_classic()+
  ylim(0,1)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Alarm", "Control"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  annotate("text", x = 1.5, y = 0.95, label = "*", size =12)+
  annotate("text", x = 0.6, y = 1, label = "c)", size =6)

Flee.Noncolony <- flee.means %>% 
  filter(Colony =="no")

ggplot(data = Flee.Noncolony, aes(x=Treatment, y=prob, colour = Treatment))+
  geom_line()+
  geom_point(size = 3)+
  geom_errorbar(aes(ymin=lower.CL, ymax=upper.CL), size = 1.2, width=.1) +
  xlab("Non-colony tree") + ylab("Probability of skinks fleeing")+ 
  theme_classic()+
  ylim(0,1)+
  theme(axis.text=element_text(size=16),
        axis.title=element_text(size=18),
        axis.title.y = element_text(margin = margin(t=0, r=20, b=0, l=0)))+ 
  scale_x_discrete(labels=c("Alarm", "Control"))+
  theme(legend.position = "none") +
  #geom_text(data = ann_text,label = "Text")
  #annotate("text", x = 1.5, y = 0.95, label = "*", size =12)+
  annotate("text", x = 0.6, y = 1, label = "d)", size =6)
